@@ -2,6 +2,7 @@ from .auth import *
 from .permissions import *
 from .routes import *
 from .service import *
+from .validation import *
 from .version import *
 
-__version__ = "0.5.4"
+__version__ = "0.6"
